==> nextcloud-23.0.9.tgz: nextcloud/apps/dashboard/l10n/hr.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Nadzorna ploča",
    "Dashboard app" : "Nadzorna ploča aplikacije",
    "Customize" : "Uredi",
    "Edit widgets" : "Uredi widgete",
    "Get more widgets from the App Store" : "Nabavite više widgeta iz trgovine aplikacijama",
    "Change background image" : "Promijenite sliku pozadinu",
    "Weather service" : "Davatelj vremenske prognoze",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Radi zaštite vaše privatnosti, podatke o vremenskoj prognozi zahtijeva vaš Nextcloud poslužitelj u vaše ime kako davatelj vremenske prognoze ne bi primio vaše osobne podatke.",
    "Weather data from Met.no" : "Podaci o vremenskoj prognozi iz Met.no",
    "geocoding with Nominatim" : "geokodiranje uz Nominatim",
    "elevation data from OpenTopoData" : "podaci o nadmorskoj visini iz OpenTopoData",
    "Weather" : "Vrijeme",
    "Status" : "Status",
    "Good morning" : "Dobro jutro",
    "Good morning, {name}" : "Dobro jutro, {name}",
    "Good afternoon" : "Dobar dan",
    "Good afternoon, {name}" : "Dobar dan, {name}",
    "Good evening" : "Dobar dan",
    "Good evening, {name}" : "Dobar dan, {name}",
    "Hello" : "Pozdrav",
    "Hello, {name}" : "Pozdrav, {name}",
    "Pick from Files" : "Odaberi iz datoteka",
    "Plain background" : "Obična pozadina",
    "Insert from {productName}" : "Umetni iz {productName}",
    "Show something" : "Prikaži nešto",
    "Default images" : "Zadane slike"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-23.0.12p1.tgz: nextcloud/apps/dashboard/l10n/hr.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Nadzorna ploča",
    "Dashboard app" : "Nadzorna ploča aplikacije",
    "Customize" : "Uredi",
    "Edit widgets" : "Uredi widgete",
    "Get more widgets from the App Store" : "Nabavite više widgeta iz trgovine aplikacijama",
    "Weather service" : "Davatelj vremenske prognoze",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Radi zaštite vaše privatnosti, podatke o vremenskoj prognozi zahtijeva vaš Nextcloud poslužitelj u vaše ime kako davatelj vremenske prognoze ne bi primio vaše osobne podatke.",
    "Weather data from Met.no" : "Podaci o vremenskoj prognozi iz Met.no",
    "geocoding with Nominatim" : "geokodiranje uz Nominatim",
    "elevation data from OpenTopoData" : "podaci o nadmorskoj visini iz OpenTopoData",
    "Weather" : "Vrijeme",
    "Status" : "Status",
    "Good morning" : "Dobro jutro",
    "Good morning, {name}" : "Dobro jutro, {name}",
    "Good afternoon" : "Dobar dan",
    "Good afternoon, {name}" : "Dobar dan, {name}",
    "Good evening" : "Dobar dan",
    "Good evening, {name}" : "Dobar dan, {name}",
    "Hello" : "Pozdrav",
    "Hello, {name}" : "Pozdrav, {name}",
    "Show something" : "Prikaži nešto",
    "Change background image" : "Promijenite sliku pozadinu",
    "Pick from Files" : "Odaberi iz datoteka",
    "Default images" : "Zadane slike",
    "Plain background" : "Obična pozadina",
    "Insert from {productName}" : "Umetni iz {productName}"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
